==> smartgwtee-eval-12.0p.zip: com/smartgwt/logicalstructure/widgets/calendar/CalendarLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.calendar;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class CalendarLogicalStructure extends CanvasLogicalStructure {
    public String addEventButtonHoverText;
    public String allowDurationEvents;
    public String alternateLaneStyles;
    public String alwaysShowEventHovers;
    public String backButtonTitle;
    public String baseStyle;
    public String bringEventsToFront;
    public String calMonthEventLinkStyle;
    public String cancelButtonTitle;
    public String canCreateEvents;
    public String canDeleteEvents;
    public String canDragCreateEvents;
    public String canDragEventField;
    public String canDragEvents;
    public String canEditEvents;
    public String canEditField;
    public String canEditLane;
    public String canEditLaneField;
    public String canEditSublane;
    public String canEditSublaneField;
    public String canGroupLanes;
    public String canRemoveEvents;
    public String canRemoveField;
    public String canReorderLanes;
    public String canResizeEventField;
    public String canResizeEvents;
    public String canResizeTimelineEvents;
    public String canSelectEvents;
    public String chosenDate;
    public String columnsPerPage;
    public String currentViewName;
    public CalendarEvent[] data;
    public String dataFetchMode;
    public String dateEditingStyle;
    public String dateFormatter;
    public String datePickerHoverText;
    public String dayBodyBaseStyle;
    public String dayHeaderBaseStyle;
    public String dayViewTitle;
    public String defaultTimelineColumnSpan;
    public String descriptionField;
    public String detailsButtonTitle;
    public String disableWeekends;
    public String durationField;
    public String durationUnitField;
    public String endDate;
    public String endDateField;
    public String eventAutoArrange;
    public String eventDescriptionFieldTitle;
    public FormItem[] eventDialogFields;
    public String eventDragGap;
    public String eventDurationFieldTitle;
    public String eventDurationUnitFieldTitle;
    public FormItem[] eventEditorFields;
    public String eventEndDateFieldTitle;
    public String eventHeaderHeight;
    public String eventHeaderWrap;
    public String eventLaneFieldTitle;
    public String eventNameFieldTitle;
    public String eventOverlap;
    public String eventOverlapIdenticalStartTimes;
    public String eventOverlapPercent;
    public String eventSnapGap;
    public String eventStartDateFieldTitle;
    public String eventStyleName;
    public String eventStyleNameField;
    public String eventSublaneFieldTitle;
    public String eventWindowStyle;
    public String eventWindowStyleField;
    public String firstDayOfWeek;
    public HeaderLevel[] headerLevels;
    public String hideUnusedLanes;
    public CalendarEvent[] indicators;
    public String indicatorStyleName;
    public String invalidDateMessage;
    public String laneEventPadding;
    public ListGridField[] laneFields;
    public String laneGroupByFieldAsString;
    public String laneGroupStartOpenAsString;
    public String laneNameField;
    public Lane[] lanes;
    public String leadingDateField;
    public String minimalUI;
    public String minimumDayHeight;
    public String minLaneWidth;
    public String minutesPerRow;
    public String monthButtonTitle;
    public String monthMoreEventsLinkTitle;
    public String monthViewTitle;
    public String nameField;
    public String nextButtonHoverText;
    public String otherDayBlankStyle;
    public String otherDayBodyBaseStyle;
    public String otherDayHeaderBaseStyle;
    public SortSpecifier[] overlapSortSpecifiers;
    public String previousButtonHoverText;
    public String removeButtonTitle;
    public String renderEventsOnDemand;
    public String rowHeight;
    public String rowTitleFrequency;
    public String saveButtonTitle;
    public String scrollToWorkday;
    public String selectChosenDate;
    public String selectedCellStyle;
    public String showAddEventButton;
    public String showCellHovers;
    public String showControlsBar;
    public String showDateChooser;
    public String showDatePickerButton;
    public String showDayHeaders;
    public String showDayLanes;
    public String showDayView;
    public String showDetailFields;
    public String showDragHovers;
    public String showEventDescriptions;
    public String showEventHeaders;
    public String showEventHovers;
    public String showHeaderHovers;
    public String showIndicators;
    public String showIndicatorsInFront;
    public String showLabelColumn;
    public String showLaneFieldHovers;
    public String showLaneRollOver;
    public String showMonthButton;
    public String showMonthView;
    public String showNextButton;
    public String showOtherDays;
    public String showPreviousButton;
    public String showQuickEventDialog;
    public String showTimelineView;
    public String showViewHovers;
    public String showWeekends;
    public String showWeekView;
    public String showWorkday;
    public String showZoneHovers;
    public String showZones;
    public String sizeEventsToGrid;
    public String startDate;
    public String startDateField;
    public String sublaneNameField;
    public String timeFormatter;
    public String timelineGranularity;
    public String timelineUnitsPerColumn;
    public String timelineViewTitle;
    public String todayBackgroundColor;
    public String trailingDateField;
    public String twentyFourHourTime;
    public String useEventCanvasRolloverControls;
    public String useSublanes;
    public String[] weekendDays;
    public String weekEventBorderOverlap;
    public String weekPrefix;
    public String weekViewTitle;
    public String workdayBaseStyle;
    public String workdayEnd;
    public String workdays;
    public String workdayStart;
    public CalendarEvent[] zones;
    public String zoneStyleName;
    public String zoneTitleOrientation;
}

==> smartgwtee-eval-14.1p.zip: com/smartgwt/logicalstructure/widgets/calendar/CalendarLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.calendar;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.util.tour.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class CalendarLogicalStructure extends CanvasLogicalStructure {
    public String addEventButtonHoverText;
    public String allDayField;
    public String allowDurationEvents;
    public String allowLongEvents;
    public String alternateLaneStyles;
    public String alwaysShowEventHovers;
    public String backButtonIconSrc;
    public String backButtonTitle;
    public String baseStyle;
    public String bringEventsToFront;
    public String calMonthEventLinkStyle;
    public String cancelButtonTitle;
    public String canCreateEvents;
    public String canCreateOtherDayEvents;
    public String canDeleteEvents;
    public String canDragCreateEvents;
    public String canDragEventField;
    public String canDragEvents;
    public String canEditEvents;
    public String canEditField;
    public String canEditLane;
    public String canEditLaneField;
    public String canEditSublane;
    public String canEditSublaneField;
    public String canGroupLanes;
    public String canRemoveEvents;
    public String canRemoveField;
    public String canReorderLanes;
    public String canResizeEventField;
    public String canResizeEvents;
    public String canResizeTimelineEvents;
    public String canSelectEvents;
    public String chosenDate;
    public String columnsPerPage;
    public String controlBarIconBaseStyle;
    public String controlBarIconSize;
    public String controlsBarHeight;
    public String currentViewName;
    public CalendarEvent[] data;
    public String dataFetchMode;
    public String dateEditingStyle;
    public String dateFormatter;
    public String datePickerHoverText;
    public String dayBodyBaseStyle;
    public String dayHeaderBaseStyle;
    public String dayViewTitle;
    public String defaultTimelineColumnSpan;
    public String descriptionField;
    public String detailsButtonTitle;
    public String disableWeekends;
    public String durationField;
    public String durationUnitField;
    public String endDate;
    public String endDateField;
    public String eventAllDayFieldTitle;
    public String eventAutoArrange;
    public String eventCanvasCloseButtonSize;
    public String eventCanvasCloseIconSize;
    public String eventDescriptionFieldTitle;
    public FormItem[] eventDialogFields;
    public String eventDragGap;
    public String eventDurationFieldTitle;
    public String eventDurationUnitFieldTitle;
    public String[] eventEditorButtons;
    public String eventEditorDateFieldTitle;
    public FormItem[] eventEditorFields;
    public String eventEndDateFieldTitle;
    public String eventHeaderHeight;
    public String eventHeaderWrap;
    public String eventLaneFieldTitle;
    public String eventNameFieldTitle;
    public String eventOverlap;
    public String eventOverlapIdenticalStartTimes;
    public String eventOverlapPercent;
    public String eventScreen;
    public String eventSnapGap;
    public String eventStartDateFieldTitle;
    public String eventStyleName;
    public String eventStyleNameField;
    public String eventSublaneFieldTitle;
    public String eventWindowStyle;
    public String eventWindowStyleField;
    public String firstDayOfWeek;
    public String fixedEventHeight;
    public HeaderLevel[] headerLevels;
    public String hideUnusedLanes;
    public String includeRangeCriteria;
    public CalendarEvent[] indicators;
    public String indicatorStyleName;
    public String invalidDateMessage;
    public String laneEventPadding;
    public ListGridField[] laneFields;
    public String laneGroupByFieldAsString;
    public String laneGroupStartOpenAsString;
    public String laneNameField;
    public Lane[] lanes;
    public String leadingDateField;
    public String limitToWorkday;
    public String longEventDragOpacity;
    public String longEventHeight;
    public String longEventLayoutSpace;
    public String longEventLayoutStyleName;
    public String longEventStyleName;
    public String minimalUI;
    public String minimumDayHeight;
    public String minLaneHeight;
    public String minLaneWidth;
    public String minRowHeight;
    public String minutesPerRow;
    public String monthButtonIconSrc;
    public String monthButtonTitle;
    public String monthMoreEventsLinkTitle;
    public String monthViewTitle;
    public String nameField;
    public String newEventWindowTitle;
    public String newLongEventName;
    public String nextButtonHoverText;
    public String otherDayBlankStyle;
    public String otherDayBodyBaseStyle;
    public String otherDayClickNavigation;
    public String otherDayHeaderBaseStyle;
    public SortSpecifier[] overlapSortSpecifiers;
    public String previousButtonHoverText;
    public String removeButtonTitle;
    public String renderEventsOnDemand;
    public String rowHeight;
    public String rowTitleFrequency;
    public String saveButtonTitle;
    public String scrollToWorkday;
    public String selectChosenDate;
    public String selectedCellStyle;
    public String showAddEventButton;
    public String showCellHovers;
    public String showColumnLayouts;
    public String showControlsBar;
    public String showDateChooser;
    public String showDatePickerButton;
    public String showDayHeaders;
    public String showDayLanes;
    public String showDayView;
    public String showDetailFields;
    public String showDragHovers;
    public String showEventCanvasComponents;
    public String showEventDescriptions;
    public String showEventHeaders;
    public String showEventHovers;
    public String showHeaderHovers;
    public String showIndicators;
    public String showIndicatorsInFront;
    public String showLabelColumn;
    public String showLaneFieldHovers;
    public String showLaneRollOver;
    public String showMonthButton;
    public String showMonthView;
    public String showNextButton;
    public String showOtherDays;
    public String showPreviousButton;
    public String showQuickEventDialog;
    public String showTimelineView;
    public String showViewHovers;
    public String showWeekends;
    public String showWeekView;
    public String showWorkday;
    public String showZoneHovers;
    public String showZones;
    public String sizeEventsToGrid;
    public String sizeToWorkday;
    public String startDate;
    public String startDateField;
    public String styleWorkday;
    public String sublaneNameField;
    public String timeFormatter;
    public String timelineGranularity;
    public String timelineUnitsPerColumn;
    public String timelineViewTitle;
    public String todayBackgroundColor;
    public String trailingDateField;
    public String twentyFourHourTime;
    public String useEventCanvasRolloverControls;
    public String useSublanes;
    public String[] weekendDays;
    public String weekEventBorderOverlap;
    public String weekPrefix;
    public String weekViewTitle;
    public String workdayBaseStyle;
    public String workdays;
    public CalendarEvent[] zones;
    public String zoneStyleName;
    public String zoneTitleOrientation;
}
